# -*- coding: utf-8 -*-
# @Organization  : TMT
# @Author        : Cuong Tran
# @Time          : 11/7/2022

from .data import folder_dataset_split
from .plot import plot_cm
from .calc import calc_euclidean



# -*- coding: utf-8 -*-
# @Organization  : TMT
# @Author        : Cuong Tran
# @Time          : 11/7/2022

import numpy as np


def calc_euclidean(feat1, feat2):
    feat1 = feat1.ravel()
    feat2 = feat2.ravel()
    return np.dot(feat1, feat2) / (np.linalg.norm(feat1) * np.linalg.norm(feat2))



# -*- coding: utf-8 -*-
# @Organization  : TMT
# @Author        : Cuong Tran
# @Time          : 11/7/2022
import os
import random
import shutil
from multiprocessing import Process


def _move_files_list(data, src, dst):
    for idx, d in enumerate(data):
        path_ori_data = os.path.join(src, d)
        shutil.copy(path_ori_data, dst)


def folder_dataset_split(root_path, dst_path, ratio_train=0.8):
    os.makedirs(dst_path, exist_ok=True)
    os.makedirs(os.path.join(dst_path, 'train'), exist_ok=True)
    os.makedirs(os.path.join(dst_path, 'test'), exist_ok=True)

    clss = os.listdir(root_path)
    for cls in clss:
        path = os.path.join(root_path, cls)
        if os.path.isdir(path):
            new_train_path = os.path.join(os.path.join(dst_path, 'train', cls))
            new_test_path = os.path.join(os.path.join(dst_path, 'test', cls))
            os.makedirs(new_train_path, exist_ok=True)
            os.makedirs(new_test_path, exist_ok=True)

            data = os.listdir(path)
            random.shuffle(data)

            pivot = int(ratio_train * len(data))
            train_data = data[:pivot]
            test_data = data[pivot:]
            Process(target=_move_files_list, args=(train_data, path, new_train_path)).start()
            Process(target=_move_files_list, args=(test_data, path, new_test_path)).start()

            # for idx, d in enumerate(data):
            #     path_ori_data = os.path.join(path, d)
            #     path_dst_data = new_train_path if idx <= pivot else new_test_path
            #     shutil.copy(path_ori_data, path_dst_data)


if __name__ == '__main__':
    folder_dataset_split(r'F:\Zalo Live Face\image_224_dataset', r'F:\Zalo Live Face\image_224_dataset_split')



# -*- coding: utf-8 -*-
# @Organization  : TMT
# @Author        : Cuong Tran
# @Time          : 11/7/2022


import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), "README.md")) as readme:
    README = readme.read()

setup(
    name="ppprocess",
    version="0.0.1",
    author="Cuong Tran",
    author_email="cuongtran73d1@gmail.com",
    description="My utils for AI",
    long_description="For my self",
    long_description_content_type="text/markdown",
    url="https://github.com/cuongdtone/ppprocess",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



# -*- coding: utf-8 -*-
# @Organization  : TMT
# @Author        : Cuong Tran
# @Time          : 11/7/2022

import warnings
from pathlib import Path
import matplotlib.pyplot as plt
import numpy as np


def plot_cm(CM, normalize=True, save_dir='', names=(), show=True, title=''):
    if True:
        import seaborn as sn
        array = CM/((CM.sum(0).reshape(1, -1) + 1E-6) if normalize else 1)  # normalize columns
        if not normalize:
            array = np.asarray(array, dtype='int')
        fmt = 'd'
        if normalize:
            fmt = '.2f'
            array[array < 0.005] = np.nan  # don't annotate (would appear as 0.00)
        fig = plt.figure(figsize=(12, 9), tight_layout=True)
        sn.set(font_scale=1.0 if 2 < 50 else 0.8)  # for label size
        labels = (0 < len(names) < 99) and len(names) == 2  # apply names to ticklabels
        with warnings.catch_warnings():
            warnings.simplefilter('ignore')  # suppress empty matrix RuntimeWarning: All-NaN slice encountered
            sn.heatmap(array, annot=2 < 30, annot_kws={"size": 8}, cmap='Blues', fmt=fmt, square=True,
                       xticklabels=names if labels else "auto",
                       yticklabels=names if labels else "auto").set_facecolor((1, 1, 1))
        fig.axes[0].set_xlabel('True')
        fig.axes[0].set_ylabel('Predicted')
        fig.axes[0].set_title(title)
        if show:
            plt.show()
        name_save = 'confusion_matrix.png'
        if normalize:
            name_save = 'confusion_matrix_normalize.png'
        fig.savefig(Path(save_dir) / name_save, dpi=250)
        plt.close()
